@@ -104,8 +104,7 @@ class OutputBase(object):
         if remote:
             parsed = urlparse(path)
             return remote.path_info / parsed.path.lstrip("/")
-        else:
-            return self.REMOTE.path_cls(path)
+        return self.REMOTE.path_cls(path)
 
     def __repr__(self):
         return "{class_name}: '{def_path}'".format(
@@ -138,11 +137,6 @@ class OutputBase(object):
     def dir_cache(self):
         return self.cache.get_dir_cache(self.checksum)
 
-    def assign_to_stage_file(self, target_repo):
-        raise DvcException(
-            "change repo is not supported for {}".format(self.scheme)
-        )
-
     @classmethod
     def supported(cls, url):
         return cls.REMOTE.supported(url)
