@@ -1,15 +1,19 @@
 from __future__ import unicode_literals
 
 import logging
+from funcy.py3 import cat
 
 
 logger = logging.getLogger(__name__)
 
 
-def _local_status(self, target=None, with_deps=False):
+def _local_status(self, targets=None, with_deps=False):
     status = {}
 
-    stages = self.collect(target, with_deps=with_deps)
+    if targets:
+        stages = cat(self.collect(t, with_deps=with_deps) for t in targets)
+    else:
+        stages = self.collect(None, with_deps=with_deps)
 
     for stage in stages:
         if stage.locked:
@@ -27,10 +31,9 @@ def _local_status(self, target=None, with_deps=False):
 
 def _cloud_status(
     self,
-    target=None,
+    targets=None,
     jobs=None,
     remote=None,
-    show_checksums=False,
     all_branches=False,
     with_deps=False,
     all_tags=False,
@@ -64,7 +67,7 @@ def _cloud_status(
     import dvc.remote.base as cloud
 
     used = self.used_cache(
-        target,
+        targets,
         all_branches=all_branches,
         all_tags=all_tags,
         with_deps=with_deps,
@@ -74,10 +77,8 @@ def _cloud_status(
     )["local"]
 
     ret = {}
-    status_info = self.cloud.status(
-        used, jobs, remote=remote, show_checksums=show_checksums
-    )
-    for md5, info in status_info.items():
+    status_info = self.cloud.status(used, jobs, remote=remote)
+    for info in status_info.values():
         name = info["name"]
         status = info["status"]
         if status in [cloud.STATUS_OK, cloud.STATUS_MISSING]:
@@ -92,11 +93,10 @@ def _cloud_status(
 
 def status(
     self,
-    target=None,
+    targets=None,
     jobs=None,
     cloud=False,
     remote=None,
-    show_checksums=False,
     all_branches=False,
     with_deps=False,
     all_tags=False,
@@ -105,12 +105,11 @@ def status(
         if cloud or remote:
             return _cloud_status(
                 self,
-                target,
+                targets,
                 jobs,
-                remote=remote,
-                show_checksums=show_checksums,
                 all_branches=all_branches,
                 with_deps=with_deps,
+                remote=remote,
                 all_tags=all_tags,
             )
-        return _local_status(self, target, with_deps=with_deps)
+        return _local_status(self, targets, with_deps=with_deps)
